# python3 -m pip install botrun-pdf-to-text
```
from botrun_pdf_to_text import botrun_pdf_to_text
# convert a folder of pdfs to text pages
botrun_pdf_to_text("./users/cbh_cameo_tw/data/upload_files")
# convert multiple pdf files to text pages
botrun_pdf_to_text(["./users/cbh_cameo_tw/data/upload_files/222715345.pdf"])
```